@@ -632,7 +632,7 @@ void key_box (const char ktext[], int command)
 	rectfill (display, 210, 200, 430, 250, COL_OUTLINE);
 	rect (display, 211, 201, 429, 249, COL_COL1);
 
-	textprintf_centre_ex (display, font, 320, 222, -1, -1, ktext);
+	textprintf_centre_ex (display, font, 320, 222, -1, -1, "%s", ktext);
 
 	vsync ();
 	blit (display, screen, 0, 0, 0, 0, 640, 480);
